# Rate Limiting

Protect your API from abuse and manage throughput with flexible rate limits.
You can set global limits, per‑model limits, and choose a storage backend for
counters.

## Sections

- [Configuration](configuration.md)
- [Storage backends](storage-backends.md)
